@@ -1915,7 +1915,7 @@ class Imagen(nn.Module):
             text_embeds = text_embeds,
             text_mask = text_mask,
             cond_images = cond_images,
-            lowres_noise_times = noise_scheduler.get_condition(lowres_aug_times),
+            lowres_noise_times = self.lowres_noise_schedule.get_condition(lowres_aug_times),
             lowres_cond_img = lowres_cond_img_noisy,
             cond_drop_prob = self.cond_drop_prob,
         )
